@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.22 2004/02/14 19:28:55 yeupou Exp $
+# $Id: sv_update_conf.pl,v 1.23 2004/08/23 12:47:54 yeupou Exp $
 #
 #
 #
@@ -171,9 +171,12 @@ sub AskSetting {
     # Now, we set $$item to how we want to show it in the configuration
     # file.
     if ($$item eq "" || $$item eq "OUT") {
-	$$item = "# our \$$item=\"\"\;";
+	$$item = "# our \$$item=\'\'\;";
     } else {
-	$$item = "our \$$item=\"$$item\"\;"; 	
+	# Escape quotes
+	$$item =~ s/\'/\\\'/g;
+	# Add the entry
+	$$item = "our \$$item=\'$$item\'\;"; 	
     }
 }
 
@@ -297,7 +300,7 @@ if ($recreate) {
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.22 2004/02/14 19:28:55 yeupou Exp $
+# $Id: sv_update_conf.pl,v 1.23 2004/08/23 12:47:54 yeupou Exp $
 #
 #
 # Savannah Site Configuration:
