@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: i18n.php,v 1.9 2004/03/13 18:22:06 yeupou Exp $
+# $Id: i18n.php,v 1.11 2004/07/29 19:42:10 tchernobog Exp $
 #
 #  Copyright 2003-2004 (c) Stphane Urbanovski <s.urbanovski@ac-nancy-metz.fr>
 #                          Mathieu Roy <yeupou--at--gnu.org>              
@@ -41,6 +41,8 @@ $supportedLanguages = array(
 			    "es_ES"	=> "ES",
 			    "fr"	=> "FR",
 			    "fr_FR"	=> "FR",
+			    "it"	=> "IT",
+			    "it_IT"     => "IT",
 			    "ja"	=> "JA",
 			    "ko"	=> "KO",
 			    "pt"	=> "BR",
