@@ -1,32 +1,27 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: forum.php,v 1.3 2004/01/31 00:56:18 yeupou Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation
-// 
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: forum.php,v 1.4 2004/03/13 18:22:06 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#
+#  Copyright 2004      (c) ...
+# 
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 function forum_show_a_nested_message ($result,$row=0) 
 {
@@ -43,8 +38,8 @@ function forum_show_a_nested_message ($result,$row=0)
     
 	$g_id =  db_result($result,$row,'group_id');
     
-	// if the forum is a piece of news then get the real group_id from the
-	// news_byte table
+	# if the forum is a piece of news then get the real group_id from the
+	# news_byte table
 	if ($g_id == $GLOBALS['sys_group_id']) 
         {
             $f_id =  db_result($result,$row,'group_forum_id');
@@ -99,14 +94,14 @@ function forum_show_nested_messages ($thread_id, $msg_id) {
             */
             for ($i=0; $i<$rows; $i++) 
                 {
-                    //	increment the global total count
+                    #	increment the global total count
                     $total_rows++;
 			
-                    //	show the actual nested message
+                    #	show the actual nested message
                     $ret_val .= forum_show_a_nested_message ($result,$i).'<P>';
                     if (db_result($result,$i,'has_followups') > 0) 
                         {
-                            //	Call yourself if there are followups
+                            #	Call yourself if there are followups
                             $ret_val .= forum_show_nested_messages ( $thread_id, db_result($result,$i,'msg_id') );
                         }
                 }
@@ -117,7 +112,7 @@ function forum_show_nested_messages ($thread_id, $msg_id) {
 	return $ret_val;
 }
 
-// FIXME: site_project_header function should be used instead
+# FIXME: site_project_header function should be used instead
 function forum_header($params)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':forum_header($params)';
@@ -126,31 +121,31 @@ function forum_header($params)
 	$params['group']=$group_id;
 	$params['toptab']='forum';
  
-	// NEWS ADMIN
-	//this is a news item for the whole system or a for a project,
-	// not a regular forum: forum are deactivated in savannah
+	# NEWS ADMIN
+	#this is a news item for the whole system or a for a project,
+	# not a regular forum: forum are deactivated in savannah
 	if ($forum_id)
         {
-            // Show this news item at the top of the page
+            # Show this news item at the top of the page
             $sql="SELECT * FROM news_bytes WHERE forum_id='$forum_id'";
             $result=db_query($sql);	
 				
-            // if the result is empty, this is not a news item, but a forum.
+            # if the result is empty, this is not a news item, but a forum.
             if (!$result || db_numrows($result) < 1)
                 {	
                     $is_news=0;
-                    //echo '<font class="error">'._("Error").' - '._("This news item was not found").'</font>';
-                    //echo "forum_name=$forum_name<br>";
+                    #echo '<font class="error">'._("Error").' - '._("This news item was not found").'</font>';
+                    #echo "forum_name=$forum_name<br>";
                     site_project_header($params);
-                    //site_project_header(array('group'=>$group_id,'toptab'=>'forum'));	
+                    #site_project_header(array('group'=>$group_id,'toptab'=>'forum'));	
                 } 
             else
                 {
                     $is_news=1;
-                    //backwards shim for all "generic news" that used to be submitted
-                    //as of may, "generic news" is not permitted - only project-specific news
+                    #backwards shim for all "generic news" that used to be submitted
+                    #as of may, "generic news" is not permitted - only project-specific news
 			
-		    // FIXME: group_name is not set, it brokes the top menu.
+		    # FIXME: group_name is not set, it brokes the top menu.
  
                     $params['group']=db_result($result,0,'group_id');
 			
@@ -189,10 +184,10 @@ function forum_header($params)
 	if ($forum_id && user_isloggedin())
         {
             echo '<a href="'.$GLOBALS['sys_home'].'forum/monitor.php?forum_id='.$forum_id.'">' .
-                //'<img src="'.$GLOBALS['sys_home'].'images/ic/check.png" alt="monitor">
+                #'<img src="'.$GLOBALS['sys_home'].'images/ic/check.png" alt="monitor">
                 _("Monitor Forum (toggle)").'</a> | '.
                 '<a href="'.$GLOBALS['sys_home'].'forum/save.php?forum_id='.$forum_id.'">'.
-                //'<img src="'.$GLOBALS['sys_home'].'images/ic/save.png" alt="save"> 
+                #'<img src="'.$GLOBALS['sys_home'].'images/ic/save.png" alt="save"> 
                 _("Save Place").'</a> | '.
                 '<A HREF="'.$GLOBALS['sys_home'].'forum/who_monitors.php?forum_id='.$forum_id.'?group_id='.$group_id.'">'.
                 'Who\'s monitoring</A> | '.
@@ -209,7 +204,7 @@ function forum_header($params)
 	echo '<P>';
 }
 
-// Backward compatibility
+# Backward compatibility
 function forum_footer($params){
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':forum_footer($params)'; 
 	site_project_footer($params); 
@@ -238,7 +233,7 @@ function forum_create_forum($group_id,$forum_name,$is_public=1,$create_default_m
 	
 	if ($create_default_message)
         {
-            //set up a cheap default message
+            #set up a cheap default message
             $result2=db_query("INSERT INTO forum ".
                               "(group_forum_id,posted_by,subject,body,date,is_followup_to,thread_id) ".
                               "VALUES ('$forum_id','100','Welcome to $forum_name',".
@@ -250,7 +245,7 @@ function forum_create_forum($group_id,$forum_name,$is_public=1,$create_default_m
 function make_links ($data="")
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':make_links ($data="")';
-	//moved make links to /include/utils.php
+	#moved make links to /include/utils.php
 	utils_make_links($data);
 }
 
@@ -473,7 +468,7 @@ function get_forum_saved_date($forum_id)
                 } 
             else
                 {
-                    //highlight new messages from the past week only
+                    #highlight new messages from the past week only
                     $forum_saved_date=(time()-604800);
                     return $forum_saved_date;
                 }
@@ -495,7 +490,7 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
                     exit_error('Error',_("Must include a message body and subject"));
                 }
 		
-            //see if that message has been posted already for all the idiots that double-post
+            #see if that message has been posted already for all the idiots that double-post
             $res3=db_query("SELECT * FROM forum ".
                            "WHERE is_followup_to='$is_followup_to' ".
                            "AND subject='".  htmlspecialchars($subject) ."' ".
@@ -504,7 +499,7 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
 		
             if (db_numrows($res3) > 0)
                 {
-                    //already posted this message
+                    #already posted this message
                     exit_error('Error',_("You appear to be double-posting this message, since it has the same subject and followup information as a prior post."));
                 } 
             else
@@ -521,17 +516,17 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
                 {
                     if ($is_followup_to)
                         {
-                            //increment the parent's followup count if necessary
+                            #increment the parent's followup count if necessary
                             $res2=db_query("SELECT * FROM forum WHERE msg_id='$is_followup_to' AND thread_id='$thread_id' AND group_forum_id='$group_forum_id'");
                             if (db_numrows($res2) > 0)
                                 {
                                     if (db_result($result,0,'has_followups') > 0)
                                         {
-                                            //parent already is marked with followups
+                                            #parent already is marked with followups
                                         } 
                                     else
                                         {
-                                            //mark the parent with followups as an optimization later
+                                            #mark the parent with followups as an optimization later
                                             db_query("UPDATE forum SET has_followups='1' WHERE msg_id='$is_followup_to' AND thread_id='$thread_id' AND group_forum_id='$group_forum_id'");
                                         }
                                 } 
@@ -542,7 +537,7 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
                         } 
                     else
                         {
-                            //should never happen except with shoddy browsers or mucking with the HTML form
+                            #should never happen except with shoddy browsers or mucking with the HTML form
                             exit_error('Error',_("No followup ID present when trying to post to an existing thread."));
                         }
                 }
@@ -584,7 +579,7 @@ function show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")
         {
             if ($subject)
                 {
-                    //if this is a followup, put a RE: before it if needed
+                    #if this is a followup, put a RE: before it if needed
                     if (!eregi('RE:',$subject,$test))
                         {
                             $subject ='RE: '.$subject;
@@ -689,15 +684,15 @@ function handle_monitoring($forum_id,$msg_id)
                                 "\nTo stop monitoring this forum, login to Savannah and visit: ".
                                 "\nhttp://$GLOBALS[sys_default_domain]/forum/monitor.php?forum_id=$forum_id";
                             $savannah_project=db_result($result,0,'unix_group_name');
-                            //$savannah_artifact="Forum";
-                            //$savannah_artifact_id=$forum_id;
-                            $savannah_artifact=0; // these must stay zero to not mess up the subject any further
+                            #$savannah_artifact="Forum";
+                            #$savannah_artifact_id=$forum_id;
+                            $savannah_artifact=0; # these must stay zero to not mess up the subject any further
                             $savannah_artifact_id=0;
                             $reply_to=$GLOBALS['sys_lists_prefix'] . db_result($result,0,'unix_group_name').
                                 "_" . db_result($result,0,'forum_name') . "@" . $GLOBALS['sys_default_domain'];
                             $additional_headers="BCC: $tolist";
 
-// Custom extensions to the header:
+# Custom extensions to the header:
 /*
                             echo "Just executed <br>".
                             "sendmail_mail (from: $from, <br>to: $to, <br>subject: $subject, <br>message: $message, <br>".
@@ -784,7 +779,7 @@ function recursive_delete($msg_id,$forum_id)
 	return $count;
 }
 
-// US validate forum
+# US validate forum
 function validate_forum_name ($forum_name) {
     return (ereg('^[a-zA-Z0-9\-]+$',$forum_name));
 }
