@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: browse.php,v 1.27 2004/03/13 18:22:06 yeupou Exp $
+# $Id: browse.php,v 1.29 2004/06/28 14:21:32 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -286,10 +286,12 @@ while ($field = trackers_list_all_fields())
    Start building the SQL query (select and where clauses)
   ================================================== */
 
-# Force the selection of severity because it is always shown as color code
+# Force the selection of priority because it is always shown as color code
+# Force the selection of privacy, we always want to be sure that no private
+# item title is provided to everybody.
 $col_list = $lbl_list = array();
 $select_count = 'SELECT count(*) AS count ';
-$select = 'SELECT '.ARTIFACT.'.priority ';
+$select = 'SELECT '.ARTIFACT.'.priority,'.ARTIFACT.'.privacy  ';
 $from = 'FROM '.ARTIFACT.' ';
 $where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
 if (!$pv)
@@ -400,7 +402,6 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
 
     } else if (trackers_data_is_date_field($field) ){
 
-      $load_cal = true; # We need to load the Javascript Calendar
       if ($advsrch)
 	$boxes .= trackers_multiple_field_date($field,$prefs[$field][0],
 					       $prefs[$field.'_end'][0],0,0,$pv);
@@ -500,12 +501,6 @@ else
   trackers_header(array('title'=>_("Browse").' '.$hdr));
 }
 
-if ($load_cal)
-{
-  echo ' <script language="JavaScript" src="'.
-    $GLOBALS['sys_home'].'include/calendar.js"></script> ';
-}
-
 echo '    <FORM ACTION="'.$PHP_SELF .'" METHOD="GET" NAME="bug_form">
           <INPUT TYPE="HIDDEN" NAME="group_id" VALUE="'.$group_id.'">
           <INPUT TYPE="HIDDEN" NAME="set" VALUE="custom">
