@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.50 2004/03/13 18:22:05 yeupou Exp $
+# $Id: index.php,v 1.51 2004/08/23 13:30:24 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #
@@ -62,7 +62,7 @@ print '</td><td class="indexright">';
 print show_features_boxes();
 
 $HTML->box1_top(_("Help Wanted"));
-print people_show_category_list();
+print '<font class="small">'.people_show_category_list().'<font>';
 $HTML->box1_bottom();
 
 print '</td></tr></table>';
